@@ -15,11 +15,13 @@ has '+component_name' => (
     'default' => 'thoriumtestcomponent'
 );
 
-has '+component' => (
-    'default' => sub {
-        [ $FindBin::Bin . '/etc/component.yaml', $FindBin::Bin . '/etc/local.yaml' ]
-    }
-);
+has '+component' => ('builder' => '_build_component');
+
+sub _build_component {
+     return [ $FindBin::Bin . '/etc/component.yaml', $FindBin::Bin . '/etc/local.yaml' ]
+}
+
+has '+component_root' => ('default' => $FindBin::Bin );
 
 no Moose;
 __PACKAGE__->meta->make_immutable;
